==> rsyncy-0.0.2.tgz: package/lib/app.js <==
module.exports = function() {

  const Watchman = require('./watchman');
  const Sync = require('./sync');
  const prettyms = require('pretty-ms');

  const assert = require('assert');

  class App {
    constructor(opts) {
      assert(opts.source, 'source path is required');
      assert(opts.target, 'target path is required');
      opts.exclude = opts.exclude || [];
      this.opts = opts;
    }

    get _watchman() {
      if(!this.__watchman) {
        let { source, exclude } = this.opts;
        this.__watchman = new Watchman({ source, exclude });
      }
      return this.__watchman;
    }

    get _sync() {
      if(!this.__sync) {
        let { source, target, exclude } = this.opts;
        this.__sync = new Sync({ source, target, exclude });
      }
      return this.__sync;
    }

    _onChange(files) {
      for(let file of files) {
        let marker = '';
        if(!file.exists) {
          marker = ' (deleted)';
        }
        console.log(`× ${file.name}${marker}`);
      }
      this._sync.subset(files.map(file => file.name)).then(null, err => console.log(err));
    }

    _onSynced(took) {
      console.log('→', 'took', prettyms(took));
    }

    start() {
      let watchman = this._watchman;

      let sync = this._sync;
      sync.on('done', took => this._onSynced(took));

      let opts = this.opts;
      console.log(`→ rsyncy: ${opts.source} → ${opts.target} (w/o ${opts.exclude.join(', ')})`);

      return Promise.resolve()
        .then(() => watchman.start()).then(() => watchman.on('change', files => this._onChange(files)))
        .then(() => sync.start())
        .then(null, err => console.log(err));
    }

    static start(opts) {
      let app = new this(opts);
      return app.start();
    }
  }

  return App;
}();

==> rsyncy-0.0.4.tgz: package/lib/app.js <==
module.exports = function() {

  const Watchman = require('./watchman');
  const Sync = require('./sync');
  const prettyms = require('pretty-ms');

  const assert = require('assert');

  class App {
    constructor(opts) {
      assert(opts.source, 'source path is required');
      assert(opts.target, 'target path is required');
      opts.exclude = opts.exclude || [];
      this.opts = opts;
    }

    get _watchman() {
      if(!this.__watchman) {
        let { source, exclude } = this.opts;
        this.__watchman = new Watchman({ source, exclude });
      }
      return this.__watchman;
    }

    get _sync() {
      if(!this.__sync) {
        let { source, target, exclude } = this.opts;
        this.__sync = new Sync({ source, target, exclude });
      }
      return this.__sync;
    }

    _onChange(files) {
      for(let file of files) {
        let marker = '';
        if(!file.exists) {
          marker = ' (deleted)';
        }
        console.log(`× ${file.name}${marker}`);
      }
      this._sync.subset(files.map(file => file.name)).then(null, err => console.log(err));
    }

    _onSynced(took) {
      console.log('→', 'took', prettyms(took));
    }

    _startWatchmanIfNeeded() {
      let opts = this.opts;
      if(opts.config.once) {
        return;
      }
      let watchman = this._watchman;
      return watchman.start().then(() => watchman.on('change', files => this._onChange(files)));
    }

    _startSync() {
      let sync = this._sync;
      sync.on('done', took => this._onSynced(took));
      return sync.start();
    }

    _info() {
      let { source, target, exclude } = this.opts;
      console.log(`→ rsyncy: ${source} → ${target} (w/o ${exclude.join(', ')})`);
    }

    start() {
      this._info();
      return Promise.resolve()
        .then(() => this._startWatchmanIfNeeded())
        .then(() => this._startSync())
        .then(null, err => console.log(err));
    }

    static start(opts) {
      let app = new this(opts);
      return app.start();
    }
  }

  return App;
}();
